@@ -1,10 +1,10 @@
 package hosting_service
 
 // if you want to make a custom regex for a given service feel free to test it out
-// at regoio.herokuapp.com
+// at https://regex101.com using the flavor Golang
 var defaultUrlRegexStrings = []string{
 	`^(?:https?|ssh)://[^/]+/(?P<owner>.*)/(?P<repo>.*?)(?:\.git)?$`,
-	`^.*?@.*:(?P<owner>.*)/(?P<repo>.*?)(?:\.git)?$`,
+	`^(.*?@)?.*:/*(?P<owner>.*)/(?P<repo>.*?)(?:\.git)?$`,
 }
 var defaultRepoURLTemplate = "https://{{.webDomain}}/{{.owner}}/{{.repo}}"
 
@@ -26,7 +26,7 @@ var bitbucketServiceDef = ServiceDefinition{
 	commitURL:                       "/commits/{{.CommitHash}}",
 	regexStrings: []string{
 		`^(?:https?|ssh)://.*/(?P<owner>.*)/(?P<repo>.*?)(?:\.git)?$`,
-		`^.*@.*:(?P<owner>.*)/(?P<repo>.*?)(?:\.git)?$`,
+		`^.*@.*:/*(?P<owner>.*)/(?P<repo>.*?)(?:\.git)?$`,
 	},
 	repoURLTemplate: defaultRepoURLTemplate,
 }
@@ -75,6 +75,15 @@ var giteaServiceDef = ServiceDefinition{
 	repoURLTemplate:                 defaultRepoURLTemplate,
 }
 
+var codebergServiceDef = ServiceDefinition{
+	provider:                        "codeberg",
+	pullRequestURLIntoDefaultBranch: "/compare/{{.From}}",
+	pullRequestURLIntoTargetBranch:  "/compare/{{.To}}...{{.From}}",
+	commitURL:                       "/commit/{{.CommitHash}}",
+	regexStrings:                    defaultUrlRegexStrings,
+	repoURLTemplate:                 defaultRepoURLTemplate,
+}
+
 var serviceDefinitions = []ServiceDefinition{
 	githubServiceDef,
 	bitbucketServiceDef,
@@ -82,6 +91,7 @@ var serviceDefinitions = []ServiceDefinition{
 	azdoServiceDef,
 	bitbucketServerServiceDef,
 	giteaServiceDef,
+	codebergServiceDef,
 }
 
 var defaultServiceDomains = []ServiceDomain{
@@ -110,4 +120,9 @@ var defaultServiceDomains = []ServiceDomain{
 		gitDomain:         "try.gitea.io",
 		webDomain:         "try.gitea.io",
 	},
+	{
+		serviceDefinition: codebergServiceDef,
+		gitDomain:         "codeberg.org",
+		webDomain:         "codeberg.org",
+	},
 }
