@@ -68,7 +68,8 @@ func NewCommitFilesContext(c *ContextCommon) *CommitFilesContext {
 		},
 	}
 
-	ctx.GetView().SetOnSelectItem(ctx.SearchTrait.onSelectItemWrapper(ctx.OnSearchSelect))
+	ctx.GetView().SetRenderSearchStatus(ctx.SearchTrait.RenderSearchStatus)
+	ctx.GetView().SetOnSelectItem(ctx.OnSearchSelect)
 
 	return ctx
 }
