@@ -2,10 +2,12 @@ package context
 
 import (
 	"errors"
+	"strings"
 
 	"github.com/jesseduffield/lazygit/pkg/gui/keybindings"
 	"github.com/jesseduffield/lazygit/pkg/gui/style"
 	"github.com/jesseduffield/lazygit/pkg/gui/types"
+	"github.com/jesseduffield/lazygit/pkg/i18n"
 	"github.com/jesseduffield/lazygit/pkg/utils"
 	"github.com/samber/lo"
 )
@@ -48,9 +50,13 @@ func NewMenuContext(
 }
 
 type MenuViewModel struct {
-	c               *ContextCommon
-	menuItems       []*types.MenuItem
-	columnAlignment []utils.Alignment
+	c                         *ContextCommon
+	menuItems                 []*types.MenuItem
+	prompt                    string
+	promptLines               []string
+	columnAlignment           []utils.Alignment
+	allowFilteringKeybindings bool
+	keybindingsTakePrecedence bool
 	*FilteredListViewModel[*types.MenuItem]
 }
 
@@ -60,11 +66,29 @@ func NewMenuViewModel(c *ContextCommon) *MenuViewModel {
 		c:         c,
 	}
 
+	filterKeybindings := false
+
 	self.FilteredListViewModel = NewFilteredListViewModel(
 		func() []*types.MenuItem { return self.menuItems },
-		func(item *types.MenuItem) []string { return item.LabelColumns },
+		func(item *types.MenuItem) []string {
+			if filterKeybindings {
+				return []string{keybindings.LabelFromKey(item.Key)}
+			}
+
+			return item.LabelColumns
+		},
 	)
 
+	self.FilteredListViewModel.SetPreprocessFilterFunc(func(filter string) string {
+		if self.allowFilteringKeybindings && strings.HasPrefix(filter, "@") {
+			filterKeybindings = true
+			return filter[1:]
+		}
+
+		filterKeybindings = false
+		return filter
+	})
+
 	return self
 }
 
@@ -73,6 +97,31 @@ func (self *MenuViewModel) SetMenuItems(items []*types.MenuItem, columnAlignment
 	self.columnAlignment = columnAlignment
 }
 
+func (self *MenuViewModel) GetPrompt() string {
+	return self.prompt
+}
+
+func (self *MenuViewModel) SetPrompt(prompt string) {
+	self.prompt = prompt
+	self.promptLines = nil
+}
+
+func (self *MenuViewModel) GetPromptLines() []string {
+	return self.promptLines
+}
+
+func (self *MenuViewModel) SetPromptLines(promptLines []string) {
+	self.promptLines = promptLines
+}
+
+func (self *MenuViewModel) SetAllowFilteringKeybindings(allow bool) {
+	self.allowFilteringKeybindings = allow
+}
+
+func (self *MenuViewModel) SetKeybindingsTakePrecedence(value bool) {
+	self.keybindingsTakePrecedence = value
+}
+
 // TODO: move into presentation package
 func (self *MenuViewModel) GetDisplayStrings(_ int, _ int) [][]string {
 	menuItems := self.FilteredListViewModel.GetItems()
@@ -88,22 +137,44 @@ func (self *MenuViewModel) GetDisplayStrings(_ int, _ int) [][]string {
 			keyLabel = style.FgCyan.Sprint(keybindings.LabelFromKey(item.Key))
 		}
 
-		displayStrings = utils.Prepend(displayStrings, keyLabel)
+		checkMark := ""
+		switch item.Widget {
+		case types.MenuWidgetNone:
+			// do nothing
+		case types.MenuWidgetRadioButtonSelected:
+			checkMark = "(•)"
+		case types.MenuWidgetRadioButtonUnselected:
+			checkMark = "( )"
+		case types.MenuWidgetCheckboxSelected:
+			checkMark = "[✓]"
+		case types.MenuWidgetCheckboxUnselected:
+			checkMark = "[ ]"
+		}
+
+		displayStrings = utils.Prepend(displayStrings, keyLabel, checkMark)
 		return displayStrings
 	})
 }
 
 func (self *MenuViewModel) GetNonModelItems() []*NonModelItem {
+	result := []*NonModelItem{}
+	result = append(result, lo.Map(self.promptLines, func(line string, _ int) *NonModelItem {
+		return &NonModelItem{
+			Index:   0,
+			Column:  0,
+			Content: line,
+		}
+	})...)
+
 	// Don't display section headers when we are filtering, and the filter mode
 	// is fuzzy. The reason is that filtering changes the order of the items
 	// (they are sorted by best match), so all the sections would be messed up.
-	if self.FilteredListViewModel.IsFiltering() && self.c.UserConfig.Gui.UseFuzzySearch() {
-		return []*NonModelItem{}
+	if self.FilteredListViewModel.IsFiltering() && self.c.UserConfig().Gui.UseFuzzySearch() {
+		return result
 	}
 
-	result := []*NonModelItem{}
 	menuItems := self.FilteredListViewModel.GetItems()
-	var prevSection *types.MenuSection = nil
+	var prevSection *types.MenuSection
 	for i, menuItem := range menuItems {
 		if menuItem.Section != nil && menuItem.Section != prevSection {
 			if prevSection != nil {
@@ -139,10 +210,19 @@ func (self *MenuContext) GetKeybindings(opts types.KeybindingsOpts) []*types.Bin
 		}
 	})
 
-	// appending because that means the menu item bindings have lower precedence.
-	// So if a basic binding is to escape from the menu, we want that to still be
-	// what happens when you press escape. This matters when we're showing the menu
-	// for all keybindings of say the files context.
+	if self.keybindingsTakePrecedence {
+		// This is used for all normal menus except the keybindings menu. In this case we want the
+		// bindings of the menu items to have higher precedence than the builtin bindings; this
+		// allows assigning a keybinding to a menu item that overrides a non-essential binding such
+		// as 'j', 'k', 'H', 'L', etc. This is safe to do because the essential bindings such as
+		// confirm and return have already been removed from the menu items in this case.
+		return append(menuItemBindings, basicBindings...)
+	}
+
+	// For the keybindings menu we didn't remove the essential bindings from the menu items, because
+	// it is important to see all bindings (as a cheat sheet for what the keys are when the menu is
+	// not open). Therefore we want the essential bindings to have higher precedence than the menu
+	// item bindings.
 	return append(basicBindings, menuItemBindings...)
 }
 
@@ -156,9 +236,7 @@ func (self *MenuContext) OnMenuPress(selectedItem *types.MenuItem) error {
 		return nil
 	}
 
-	if err := self.c.PopContext(); err != nil {
-		return err
-	}
+	self.c.Context().Pop()
 
 	if selectedItem == nil {
 		return nil
@@ -175,3 +253,11 @@ func (self *MenuContext) OnMenuPress(selectedItem *types.MenuItem) error {
 func (self *MenuContext) RangeSelectEnabled() bool {
 	return false
 }
+
+func (self *MenuContext) FilterPrefix(tr *i18n.TranslationSet) string {
+	if self.allowFilteringKeybindings {
+		return tr.FilterPrefixMenu
+	}
+
+	return self.FilteredListViewModel.FilterPrefix(tr)
+}
