@@ -15,7 +15,11 @@ type PatchExplorerContext struct {
 	viewTrait              *ViewTrait
 	getIncludedLineIndices func() []int
 	c                      *ContextCommon
-	mutex                  *deadlock.Mutex
+	mutex                  deadlock.Mutex
+
+	// true if we're inside the OnSelectItem callback; in that case we don't want to update the
+	// search result index.
+	inOnSelectItemCallback bool
 }
 
 var (
@@ -36,27 +40,29 @@ func NewPatchExplorerContext(
 		state:                  nil,
 		viewTrait:              NewViewTrait(view),
 		c:                      c,
-		mutex:                  &deadlock.Mutex{},
 		getIncludedLineIndices: getIncludedLineIndices,
 		SimpleContext: NewSimpleContext(NewBaseContext(NewBaseContextOpts{
-			View:             view,
-			WindowName:       windowName,
-			Key:              key,
-			Kind:             types.MAIN_CONTEXT,
-			Focusable:        true,
-			HighlightOnFocus: true,
+			View:                       view,
+			WindowName:                 windowName,
+			Key:                        key,
+			Kind:                       types.MAIN_CONTEXT,
+			Focusable:                  true,
+			HighlightOnFocus:           true,
+			NeedsRerenderOnWidthChange: types.NEEDS_RERENDER_ON_WIDTH_CHANGE_WHEN_WIDTH_CHANGES,
 		})),
 		SearchTrait: NewSearchTrait(c),
 	}
 
-	ctx.GetView().SetOnSelectItem(ctx.SearchTrait.onSelectItemWrapper(
-		func(selectedLineIdx int) error {
-			ctx.GetMutex().Lock()
-			defer ctx.GetMutex().Unlock()
-			ctx.NavigateTo(ctx.c.Context().IsCurrent(ctx), selectedLineIdx)
-			return nil
-		}),
-	)
+	ctx.GetView().SetRenderSearchStatus(ctx.SearchTrait.RenderSearchStatus)
+	ctx.GetView().SetOnSelectItem(func(selectedLineIdx int) {
+		ctx.GetMutex().Lock()
+		defer ctx.GetMutex().Unlock()
+		ctx.inOnSelectItemCallback = true
+		ctx.NavigateTo(selectedLineIdx)
+		ctx.inOnSelectItemCallback = false
+	})
+
+	ctx.SetHandleRenderFunc(ctx.OnViewWidthChanged)
 
 	return ctx
 }
@@ -79,65 +85,71 @@ func (self *PatchExplorerContext) GetIncludedLineIndices() []int {
 	return self.getIncludedLineIndices()
 }
 
-func (self *PatchExplorerContext) RenderAndFocus(isFocused bool) {
-	self.setContent(isFocused)
+func (self *PatchExplorerContext) RenderAndFocus() {
+	self.setContent()
 
 	self.FocusSelection()
 	self.c.Render()
 }
 
-func (self *PatchExplorerContext) Render(isFocused bool) {
-	self.setContent(isFocused)
+func (self *PatchExplorerContext) Render() {
+	self.setContent()
 
 	self.c.Render()
 }
 
-func (self *PatchExplorerContext) Focus() {
-	self.FocusSelection()
-	self.c.Render()
-}
-
-func (self *PatchExplorerContext) setContent(isFocused bool) {
-	self.GetView().SetContent(self.GetContentToRender(isFocused))
+func (self *PatchExplorerContext) setContent() {
+	self.GetView().SetContent(self.GetContentToRender())
 }
 
 func (self *PatchExplorerContext) FocusSelection() {
 	view := self.GetView()
 	state := self.GetState()
-	_, viewHeight := view.Size()
-	bufferHeight := viewHeight - 1
+	bufferHeight := view.InnerHeight()
 	_, origin := view.Origin()
-	numLines := view.LinesHeight()
+	numLines := view.ViewLinesHeight()
 
 	newOriginY := state.CalculateOrigin(origin, bufferHeight, numLines)
 
 	view.SetOriginY(newOriginY)
 
-	startIdx, endIdx := state.SelectedRange()
+	startIdx, endIdx := state.SelectedViewRange()
 	// As far as the view is concerned, we are always selecting a range
 	view.SetRangeSelectStart(startIdx)
 	view.SetCursorY(endIdx - newOriginY)
+
+	if !self.inOnSelectItemCallback {
+		view.SetNearestSearchPosition()
+	}
 }
 
-func (self *PatchExplorerContext) GetContentToRender(isFocused bool) string {
+func (self *PatchExplorerContext) GetContentToRender() string {
 	if self.GetState() == nil {
 		return ""
 	}
 
-	return self.GetState().RenderForLineIndices(isFocused, self.GetIncludedLineIndices())
+	return self.GetState().RenderForLineIndices(self.GetIncludedLineIndices())
 }
 
-func (self *PatchExplorerContext) NavigateTo(isFocused bool, selectedLineIdx int) {
+func (self *PatchExplorerContext) NavigateTo(selectedLineIdx int) {
 	self.GetState().SetLineSelectMode()
 	self.GetState().SelectLine(selectedLineIdx)
 
-	self.RenderAndFocus(isFocused)
+	self.RenderAndFocus()
 }
 
 func (self *PatchExplorerContext) GetMutex() *deadlock.Mutex {
-	return self.mutex
+	return &self.mutex
 }
 
 func (self *PatchExplorerContext) ModelSearchResults(searchStr string, caseSensitive bool) []gocui.SearchPosition {
 	return nil
 }
+
+func (self *PatchExplorerContext) OnViewWidthChanged() {
+	if state := self.GetState(); state != nil {
+		state.OnViewWidthChanged(self.GetView())
+		self.setContent()
+		self.RenderAndFocus()
+	}
+}
