@@ -61,28 +61,25 @@ func (self *CommitsHelper) JoinCommitMessageAndUnwrappedDescription() string {
 }
 
 func TryRemoveHardLineBreaks(message string, autoWrapWidth int) string {
-	messageRunes := []rune(message)
 	lastHardLineStart := 0
-	for i, r := range messageRunes {
-		if r == '\n' {
+	result := message
+	for i, b := range message {
+		if b == '\n' {
 			// Try to make this a soft linebreak by turning it into a space, and
 			// checking whether it still wraps to the same result then.
-			messageRunes[i] = ' '
+			str := message[lastHardLineStart:i] + " " + message[i+1:]
+			softLineBreakIndices := gocui.AutoWrapContent(str, autoWrapWidth)
 
-			_, cursorMapping := gocui.AutoWrapContent(messageRunes[lastHardLineStart:], autoWrapWidth)
-
-			// Look at the cursorMapping to check whether auto-wrapping inserted
-			// a line break. If it did, there will be a cursorMapping entry with
-			// Orig pointing to the position after the inserted line break.
-			if len(cursorMapping) == 0 || cursorMapping[0].Orig != i-lastHardLineStart+1 {
-				// It didn't, so change it back to a newline
-				messageRunes[i] = '\n'
+			// See if auto-wrapping inserted a soft line break:
+			if len(softLineBreakIndices) > 0 && softLineBreakIndices[0] == i-lastHardLineStart+1 {
+				// It did, so change it to a space in the result.
+				result = result[:i] + " " + result[i+1:]
 			}
 			lastHardLineStart = i + 1
 		}
 	}
 
-	return string(messageRunes)
+	return result
 }
 
 func (self *CommitsHelper) SwitchToEditor() error {
