@@ -24,7 +24,33 @@ func NewConfirmationHelper(c *HelperCommon) *ConfirmationHelper {
 // This file is for the rendering of confirmation panels along with setting and handling associated
 // keybindings.
 
+func (self *ConfirmationHelper) closeAndCallConfirmationFunction(cancel goContext.CancelFunc, function func() error) error {
+	cancel()
+
+	self.c.Context().Pop()
+
+	if function != nil {
+		if err := function(); err != nil {
+			return err
+		}
+	}
+
+	return nil
+}
+
 func (self *ConfirmationHelper) wrappedConfirmationFunction(cancel goContext.CancelFunc, function func() error) func() error {
+	return func() error {
+		return self.closeAndCallConfirmationFunction(cancel, function)
+	}
+}
+
+func (self *ConfirmationHelper) wrappedPromptConfirmationFunction(
+	cancel goContext.CancelFunc,
+	function func(string) error,
+	getResponse func() string,
+	allowEmptyInput bool,
+	preserveWhitespace bool,
+) func() error {
 	return func() error {
 		if self.c.GocuiGui().IsPasting {
 			// The user is pasting multi-line text into a prompt; we don't want to handle the
@@ -34,24 +60,20 @@ func (self *ConfirmationHelper) wrappedConfirmationFunction(cancel goContext.Can
 			return nil
 		}
 
-		cancel()
-
-		self.c.Context().Pop()
-
-		if function != nil {
-			if err := function(); err != nil {
-				return err
-			}
+		response := getResponse()
+		if !preserveWhitespace {
+			response = strings.TrimSpace(response)
 		}
 
-		return nil
-	}
-}
+		if response == "" && !allowEmptyInput {
+			self.c.ErrorToast(self.c.Tr.PromptInputCannotBeEmptyToast)
+			return nil
+		}
 
-func (self *ConfirmationHelper) wrappedPromptConfirmationFunction(cancel goContext.CancelFunc, function func(string) error, getResponse func() string) func() error {
-	return self.wrappedConfirmationFunction(cancel, func() error {
-		return function(getResponse())
-	})
+		return self.closeAndCallConfirmationFunction(cancel, func() error {
+			return function(response)
+		})
+	}
 }
 
 func (self *ConfirmationHelper) DeactivateConfirmation() {
@@ -109,11 +131,7 @@ func (self *ConfirmationHelper) getPopupPanelWidth() int {
 	panelWidth := 4 * width / 7
 	minWidth := 80
 	if panelWidth < minWidth {
-		if width-2 < minWidth {
-			panelWidth = width - 2
-		} else {
-			panelWidth = minWidth
-		}
+		panelWidth = min(width-2, minWidth)
 	}
 
 	return panelWidth
@@ -134,7 +152,7 @@ func (self *ConfirmationHelper) preparePromptPanel(
 ) {
 	self.c.Views().Prompt.Title = opts.Title
 	self.c.Views().Prompt.FgColor = theme.GocuiDefaultTextColor
-	self.c.Views().Prompt.Mask = runeForMask(opts.Mask)
+	self.c.Views().Prompt.Mask = characterForMask(opts.Mask)
 	self.c.Views().Prompt.SetOrigin(0, 0)
 
 	textArea := self.c.Views().Prompt.TextArea
@@ -155,11 +173,11 @@ func (self *ConfirmationHelper) preparePromptPanel(
 	}
 }
 
-func runeForMask(mask bool) rune {
+func characterForMask(mask bool) string {
 	if mask {
-		return '*'
+		return "*"
 	}
-	return 0
+	return ""
 }
 
 func (self *ConfirmationHelper) CreatePopupPanel(ctx goContext.Context, opts types.CreatePopupPanelOpts) {
@@ -233,12 +251,15 @@ func (self *ConfirmationHelper) setConfirmationKeyBindings(cancel goContext.Canc
 
 func (self *ConfirmationHelper) setPromptKeyBindings(cancel goContext.CancelFunc, opts types.CreatePopupPanelOpts) {
 	onConfirm := self.wrappedPromptConfirmationFunction(cancel, opts.HandleConfirmPrompt,
-		func() string { return self.c.Views().Prompt.TextArea.GetContent() })
+		func() string { return self.c.Views().Prompt.TextArea.GetContent() },
+		opts.AllowEmptyInput, opts.PreserveWhitespace)
 
 	onSuggestionConfirm := self.wrappedPromptConfirmationFunction(
 		cancel,
 		opts.HandleConfirmPrompt,
 		self.getSelectedSuggestionValue,
+		opts.AllowEmptyInput,
+		opts.PreserveWhitespace,
 	)
 
 	onClose := self.wrappedConfirmationFunction(cancel, opts.HandleClose)
