@@ -35,13 +35,13 @@ func (self *SearchHelper) OpenFilterPrompt(context types.IFilterableContext) err
 
 	state.Context = context
 
-	self.searchPrefixView().SetContent(self.c.Tr.FilterPrefix)
+	self.searchPrefixView().SetContent(context.FilterPrefix(self.c.Tr))
 	promptView := self.promptView()
 	promptView.ClearTextArea()
 	self.OnPromptContentChanged("")
 	promptView.RenderTextArea()
 
-	self.c.Context().Push(self.c.Contexts().Search)
+	self.c.Context().Push(self.c.Contexts().Search, types.OnFocusOpts{})
 
 	return self.c.ResetKeybindings()
 }
@@ -58,7 +58,7 @@ func (self *SearchHelper) OpenSearchPrompt(context types.ISearchableContext) err
 	promptView.ClearTextArea()
 	promptView.RenderTextArea()
 
-	self.c.Context().Push(self.c.Contexts().Search)
+	self.c.Context().Push(self.c.Contexts().Search, types.OnFocusOpts{})
 
 	return self.c.ResetKeybindings()
 }
@@ -69,7 +69,7 @@ func (self *SearchHelper) DisplayFilterStatus(context types.IFilterableContext)
 	state.Context = context
 	searchString := context.GetFilter()
 
-	self.searchPrefixView().SetContent(self.c.Tr.FilterPrefix)
+	self.searchPrefixView().SetContent(context.FilterPrefix(self.c.Tr))
 
 	promptView := self.promptView()
 	keybindingConfig := self.c.UserConfig().Keybinding
@@ -108,20 +108,15 @@ func (self *SearchHelper) Confirm() error {
 		return self.CancelPrompt()
 	}
 
-	var err error
 	switch state.SearchType() {
 	case types.SearchTypeFilter:
 		self.ConfirmFilter()
 	case types.SearchTypeSearch:
-		err = self.ConfirmSearch()
+		self.ConfirmSearch()
 	case types.SearchTypeNone:
 		self.c.Context().Pop()
 	}
 
-	if err != nil {
-		return err
-	}
-
 	return self.c.ResetKeybindings()
 }
 
@@ -144,13 +139,13 @@ func (self *SearchHelper) ConfirmFilter() {
 	self.c.Context().Pop()
 }
 
-func (self *SearchHelper) ConfirmSearch() error {
+func (self *SearchHelper) ConfirmSearch() {
 	state := self.searchState()
 
 	context, ok := state.Context.(types.ISearchableContext)
 	if !ok {
 		self.c.Log.Warnf("Context %s is searchable", state.Context.GetKey())
-		return nil
+		return
 	}
 
 	searchString := self.promptContent()
@@ -161,7 +156,7 @@ func (self *SearchHelper) ConfirmSearch() error {
 
 	self.c.Context().Pop()
 
-	return context.GetView().Search(searchString, modelSearchResults(context))
+	context.GetView().Search(searchString, modelSearchResults(context))
 }
 
 func modelSearchResults(context types.ISearchableContext) []gocui.SearchPosition {
