@@ -11,6 +11,10 @@ var Search = NewIntegrationTest(NewIntegrationTestArgs{
 	Skip:         false,
 	SetupConfig:  func(config *config.AppConfig) {},
 	SetupRepo: func(shell *Shell) {
+		// Creating a branch avoids that searching for 't' will unexpectedly match the first commit
+		// (since it finds it in the extra info line, which is "HEAD -> master")
+		shell.NewBranch("branch")
+
 		shell.EmptyCommit("one")
 		shell.EmptyCommit("two")
 		shell.EmptyCommit("three")
@@ -31,7 +35,7 @@ var Search = NewIntegrationTest(NewIntegrationTestArgs{
 					Type("two").
 					Confirm()
 
-				t.Views().Search().Content(Contains("matches for 'two' (1 of 1)"))
+				t.Views().Search().IsVisible().Content(Contains("matches for 'two' (1 of 1)"))
 			}).
 			Lines(
 				Contains("four"),
@@ -46,7 +50,7 @@ var Search = NewIntegrationTest(NewIntegrationTestArgs{
 					Type("o").
 					Confirm()
 
-				t.Views().Search().Content(Contains("matches for 'o' (2 of 3)"))
+				t.Views().Search().IsVisible().Content(Contains("matches for 'o' (2 of 3)"))
 			}).
 			Lines(
 				Contains("four"),
@@ -56,7 +60,7 @@ var Search = NewIntegrationTest(NewIntegrationTestArgs{
 			).
 			Press("n").
 			Tap(func() {
-				t.Views().Search().Content(Contains("matches for 'o' (3 of 3)"))
+				t.Views().Search().IsVisible().Content(Contains("matches for 'o' (3 of 3)"))
 			}).
 			Lines(
 				Contains("four"),
@@ -66,7 +70,7 @@ var Search = NewIntegrationTest(NewIntegrationTestArgs{
 			).
 			Press("n").
 			Tap(func() {
-				t.Views().Search().Content(Contains("matches for 'o' (1 of 3)"))
+				t.Views().Search().IsVisible().Content(Contains("matches for 'o' (1 of 3)"))
 			}).
 			Lines(
 				Contains("four").IsSelected(),
@@ -76,7 +80,7 @@ var Search = NewIntegrationTest(NewIntegrationTestArgs{
 			).
 			Press("n").
 			Tap(func() {
-				t.Views().Search().Content(Contains("matches for 'o' (2 of 3)"))
+				t.Views().Search().IsVisible().Content(Contains("matches for 'o' (2 of 3)"))
 			}).
 			Lines(
 				Contains("four"),
@@ -86,7 +90,7 @@ var Search = NewIntegrationTest(NewIntegrationTestArgs{
 			).
 			Press("N").
 			Tap(func() {
-				t.Views().Search().Content(Contains("matches for 'o' (1 of 3)"))
+				t.Views().Search().IsVisible().Content(Contains("matches for 'o' (1 of 3)"))
 			}).
 			Lines(
 				Contains("four").IsSelected(),
@@ -96,13 +100,61 @@ var Search = NewIntegrationTest(NewIntegrationTestArgs{
 			).
 			Press("N").
 			Tap(func() {
-				t.Views().Search().Content(Contains("matches for 'o' (3 of 3)"))
+				t.Views().Search().IsVisible().Content(Contains("matches for 'o' (3 of 3)"))
 			}).
 			Lines(
 				Contains("four"),
 				Contains("three"),
 				Contains("two"),
 				Contains("one").IsSelected(),
+			).
+			NavigateToLine(Contains("three")).
+			Tap(func() {
+				t.Views().Search().IsVisible().Content(Contains("matches for 'o' (1 of 3)"))
+			}).
+			Press("N").
+			Tap(func() {
+				t.Views().Search().IsVisible().Content(Contains("matches for 'o' (1 of 3)"))
+			}).
+			Lines(
+				Contains("four").IsSelected(),
+				Contains("three"),
+				Contains("two"),
+				Contains("one"),
+			).
+			Press(keys.Universal.StartSearch).
+			Tap(func() {
+				t.ExpectSearch().
+					Type("t").
+					Confirm()
+
+				t.Views().Search().IsVisible().Content(Contains("matches for 't' (1 of 2)"))
+			}).
+			Lines(
+				Contains("four"),
+				Contains("three").IsSelected(),
+				Contains("two"),
+				Contains("one"),
+			).
+			SelectPreviousItem().
+			Tap(func() {
+				t.Views().Search().IsVisible().Content(Contains("matches for 't' (1 of 2)"))
+			}).
+			Lines(
+				Contains("four").IsSelected(),
+				Contains("three"),
+				Contains("two"),
+				Contains("one"),
+			).
+			Press("n").
+			Tap(func() {
+				t.Views().Search().IsVisible().Content(Contains("matches for 't' (1 of 2)"))
+			}).
+			Lines(
+				Contains("four"),
+				Contains("three").IsSelected(),
+				Contains("two"),
+				Contains("one"),
 			)
 	},
 })
